@@ -15,7 +15,7 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 %EXPORT_TAGS = (all => [@EXPORT_OK]);
-$VERSION = '1.0202';
+$VERSION = '1.0203';
 
 
 has permanent_path => (
@@ -649,39 +649,62 @@ These scores reflect the weight (or precedence) of the relative text-fragments,
 All of the sentences and phrase-fragments are drawn from within the existing text, and are NOT proceedurally generated.
 
 C<$summarizer->summarize_text> and C<$summarizer->summarize_file> each return a hash-ref containing three array-refs (C<$summarizer->summarize_all> returns a list of these hash-refs):
+
 =over 2
-=item *
-B<sentences> => a list of full sentences from the given article, with composite scores of the words contained therein
 
-=item *
-B<fragments> => a list of phrase fragments from the given article, scored as above
+=item B<sentences>
 
-=item *
-B<    words> => a list of all words in the article, scored by a three-factor system consisting of I<frequency of appearance>, I<population standard deviation of word clustering>, and I<use in important phrase fragments>.
+a list of full sentences from the given article, with composite scores of the words contained therein
+
+=item B<fragments>
+
+a list of phrase fragments from the given article, scored as above
+
+=item B<    words>
+
+a list of all words in the article, scored by a three-factor system consisting of I<frequency of appearance>, I<population standard deviation of word clustering>, and I<use in important phrase fragments>.
 
 The C<$summarizer->pretty_print> method prints a visually pleasing graph of the above three summary categories.
 
 The C<$summarizer->pretty_print> method prints a visually pleasing graph of the above three summary categories.
+
 =back
 
-## About Fragments
+=head2 About Fragments
+
 Phrase fragments are in actuallity short "scraps" of text (usually only two or three words) that are derived from the text via the following process:
+
 =over 8
+
 =item 1
+
 the entirety of the text is tokenized and scored into a C<frequency> table, with a high-pass threshold of frequencies above C<# of tokens * user-defined scaling factor>
+
 =item 2
+
 each sentence is tokenized and stored in an array
+
 =item 3
-for each word within the C<frequency> table, a table of phrase-fragments is derived by finding each occurance of said word and tracking forward and backward by a user-defined "radius" of tokens (defaults to C<radius = 5>, does not include the central key-word) — each phrase-fragment is thus compiled of (by default) an 11-token string
+
+for each word within the C<frequency> table, a table of phrase-fragments is derived by finding each occurance of said word and tracking forward and backward by a user-defined "radius" of tokens (defaults to C<radius = 5>, does not include the central key-word) -- each phrase-fragment is thus compiled of (by default) an 11-token string
+
 =item 4
+
 all fragments for a given key-word are then compared to each other, and each word is deleted if it appears only once amongst all of the fragments
 (leaving only C<I<A> ∪ I<B> ∪ ... ∪ I<S>> where I<A>, I<B>,...,I<S> are the phrase-fragments)
+
 =item 5
+
 what remains of each fragment is a list of "scraps" — strings of consecutive tokens — from which the longest scrap is chosen as a representation of the given phrase-fragment
+
 =item 6
+
 when a shorter fragment-scrap is included in the text of a longer scrap (i.e. a different phrase-fragment), the shorter is deleted and its score is added to the score of the longer
+
 =item 7
+
 when multiple fragments are equivalent (i.e. they consist of the same list of tokens when stopwords are excluded), they are condensed into a single scrap in the form of C<"(some|word|tokens)"> such that the fragment now represents the tokens of the scrap (excluding stopwords) regardless of order
+
 =back
 
 =head1 AUTHOR
